@@ -20,6 +20,7 @@ import os
 from datetime import datetime
 from typing import Dict, List
 
+from load_shedding.providers import eskom
 from load_shedding.providers.eskom import Province, Stage, Suburb, Provider, ProviderError
 
 
@@ -55,7 +56,7 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
         if cached and cached_schedule:
             today = datetime.now().date()
             first = datetime.strptime(cached_schedule[0][0], "%Y-%m-%d %H:%M").date()
-            if first <= today:
+            if first >= today:
                 return cached_schedule
     except FileNotFoundError as e:
         logging.log(logging.ERROR, "Unable to get schedule from cache. {e}".format(e=e))
@@ -89,3 +90,7 @@ def list_to_dict(schedule: list) -> Dict:
                 "%H:%M"),
         )
     return schedule_dict
+
+
+def get_providers() -> List[Provider]:
+    return [eskom.Eskom]
