@@ -64,6 +64,10 @@ class Eskom(Provider):
     def __init__(self):
         self.base_url = "https://loadshedding.eskom.co.za/LoadShedding"
 
+    @staticmethod
+    def name() -> str:
+        return "Eskom"
+
     @classmethod
     def province_from_name(cls, name: str) -> Province:
         return Provider.province_from_name(name)
