@@ -13,6 +13,7 @@
 #
 #      You should have received a copy of the GNU General Public License
 #      along with this program.  If not, see <https://www.gnu.org/licenses/>.
+from abc import ABC
 from enum import Enum
 
 
@@ -98,7 +99,11 @@ class Stage(Enum):
         }.get(self.value, "Unknown")
 
 
-class Provider:
+class Provider(ABC):
+    @staticmethod
+    def name() -> str:
+        return ""
+
     @classmethod
     def province_from_name(cls, name: str) -> Province:
         return {
